# pyexpsolver

This package presents an Expression class which allows for automatic solving. 
It currently lacks parenthesis support.
This package was originally meant to be used in a D&D Discord bot, so it contains methods to recognize and solve dice variables as expression operands.
